==> ts-pfsense_1.04-01.tar.gz: ts-pfsense/tssetup.php <==
<?php
/**
 *
 * Copyright(c) 2006-2016 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
 * and its suppliers and certain aspects thereof are protected by United 
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

/* prefer VERSION file contents */
$TS_VERSION="0.00";
$_tsverfile=dirname(__FILE__) . '/VERSION';
if ( file_exists( $_tsverfile ) ) {

	$TS_VERSION=trim( file_get_contents( $_tsverfile ) );
}

//Copy ThreatStop files
header('Content-type: text/plain');
if ($argc<3) {
	die ("usage: php $argv[0] blocklist allowlist\n"); 
}
$valid=file_get_contents("http://www.threatstop.com/cgi-bin/validip.pl");
if ( !strpos ($valid, "Address is in the list")) {
	die ("Please check that the IP address you registered with ThreatSTOP is the one\n".
	"below. If not please correct the address in your ThreatSTOP account and wait\n".
	"15-20 minutes, before retrying. If it is try again in a few minutes\n$valid\n"); 
}
foreach (glob("ts*") as $tsfile) {
	$newfile = "/usr/local/www/$tsfile";

	if (!copy($tsfile, $newfile)) {
	    echo "can't copy file $tsfile...\n"; die;
	}
}

$content    = trim(shell_exec("which clog"));

file_put_contents ('/usr/local/www/tslogupload.php',
	str_replace(
		'%clog%',
		$content,
		file_get_contents ('tslogupload.php')));

file_put_contents ('/usr/local/www/threatstop.conf.php',
	str_replace(
		array('%blocklist%','%allowlist%'),
		array($argv[1],$argv[2]),
		file_get_contents ('threatstop.conf.php')));

require_once("/usr/local/www/threatstop.conf.php");

echo "ThreatSTOP setup :\n";
echo "  pfSense version ${PF_VERSION}\n";
echo "  ThreatSTOP IP Firewall version ${TS_VERSION}\n";
echo "\n";

# account for differences between pfsense 2.2 and 2.3+
$nativefile = 'fbegin.inc';
if ( ( $PF_VERSION_MAJOR == 2 && $PF_VERSION_MINOR >= 3 ) || ( $PF_VERSION_MAJOR >= 3 ) ) {

	$nativefile = 'head.inc';
}

$tmpFile    = "/tmp/$nativefile" . '.tmp';
$bkfile     = dirname(__FILE__) . "/$nativefile" . ".old";
$nativepath = "/usr/local/www/$nativefile";

/*
 * Add Threatstop button into pfsense menu file...
 * Using raw dd
 * - grab bytes into a tmp file up to where we want our line
 * - write our line
 * - tack on the remainder
 *
 * ...but only if it's not already there (ie, key off of ThreatSTOP string....)
 */
if( strpos(file_get_contents($nativepath), 'ThreatSTOP') === false) {

	echo "Adding ThreatSTOP to firewall menu...\n";
	$beginfile = "/tmp/test.begin.tmp";
	$endfile = "/tmp/test.end.tmp";
	shell_exec('dd if=' . $nativepath . ' of=' . $beginfile . ' bs=`grep "firewall_menu = msort" ' . $nativepath . ' -bo | grep "[0-9]*" -o` count=1 2>/dev/null');
	shell_exec('dd if=' . $nativepath . ' of=' . $endfile   . ' skip=`grep "firewall_menu = msort" ' . $nativepath . ' -bo | grep "[0-9]*" -o` bs=1 2>/dev/null');
	copy($beginfile, $tmpFile);

	$fh = fopen($tmpFile, 'a') or die("can't open file $tmpFile");
	$stringData = "\$firewall_menu[] = array(\"ThreatSTOP \", \"/ts_state.php\");\n";
	fwrite($fh, $stringData);
	fclose($fh);
	file_put_contents($tmpFile, file_get_contents ($endfile), FILE_APPEND);
	copy ($nativepath,  $bkfile);
	copy ($tmpFile, $nativepath);
} else {

	echo "ThreatSTOP already found in menu; skipping...\n";
}

//Set crontab variables 
echo "Confirming periodic list updates are set...\n";
$cronUser= shell_exec('/usr/bin/crontab -l | sed -E -e "/\/(tsget|tslog)/d" ');
$blockmin = date ("i", time());
$upmin = date ("i", time()+300);
`echo "$cronUser
$blockmin */2 * * *      /usr/local/bin/php  /usr/local/www/tsgetblockip.php firewall 
$upmin * * * *      /usr/local/bin/php /usr/local/www/tslogupload.php /var/log/filter.log" |crontab -`;
$filter=file_get_contents ('/etc/inc/filter.inc');
$filternew =
	str_replace(
		"-ttt -i pflog0 | logger -t pf -p local0.info",
		"-ttt -i pflog0 | /usr/bin/sed -e 'N;s/\\\\n //;P;D;' | logger -t pf -p local0.info",
		$filter);
if (strcmp($filter, $filternew) !=0) {
	file_put_contents('filter.inc.new',$filternew);
	file_put_contents('filter.inc.org',$filter);
	echo "In order for ThreatSTOP to parse your logfiles you will need to do\n".
		"cp filter.inc.new /etc/inc/filter.inc\n".
		"and then reboot (see pfsense bug 1938 http://redmine.pfsense.org/issues/1938).\n\n";
}
echo "Installation complete.\n";

//Add ThreatStop lists
//Run tsgetblockip.php to make allow and block ThreatStop pf tables  
include '/usr/local/www/tsgetblockip.php';
echo "ThreatSTOP lists retrieved.\nYou can now enable ThreatSTOP in the webConfigurator.";

?>

==> ts-pfsense_1.05-02.tar.gz: ts-pfsense/tssetup.php <==
<?php
/**
 *
 * Copyright(c) 2006-2018 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
 * and its suppliers and certain aspects thereof are protected by United 
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

/* prefer VERSION file contents */
$TS_VERSION="0.00";
$_tsverfile=dirname(__FILE__) . '/VERSION';
if ( file_exists( $_tsverfile ) ) {

	$TS_VERSION=trim( file_get_contents( $_tsverfile ) );
}

header('Content-type: text/plain');

// Validation
if ($argc<4) {
	die ("usage: php $argv[0] blocklist allowlist tdid\n");
}

if (preg_match('/\.threatstop\.local$/', $argv[1]) !== 1 ) {
	die ("Unexpected Block List name\n");
}
if (preg_match('/\.threatstop\.local$/', $argv[2]) !== 1 ) {
	die ("Unexpected Allow List name\n");
}
if (preg_match('/tdid_([a-zA-Z0-9]{8})$/', $argv[3]) !== 1 ) {
	die ("Unexpected Device ID\n");
}

$valid=file_get_contents("http://www.threatstop.com/cgi-bin/validip.pl");
if ( !strpos ($valid, "Address is in the list")) {
	die ("Please check that the IP address you registered with ThreatSTOP is the one\n".
	"below. If not please correct the address in your ThreatSTOP account and wait\n".
	"15-20 minutes, before retrying. If it is try again in a few minutes\n$valid\n"); 
}
foreach (glob("ts*") as $tsfile) {
	$newfile = "/usr/local/www/$tsfile";

	if (!copy($tsfile, $newfile)) {
	    echo "can't copy file $tsfile...\n"; die;
	}
}

$content    = trim(shell_exec("which clog"));

file_put_contents ('/usr/local/www/tslogupload.php',
	str_replace(
		'%clog%',
		$content,
		file_get_contents ('tslogupload.php')));

file_put_contents ('/usr/local/www/threatstop.conf.php',
	str_replace(
		array('%blocklist%','%allowlist%', '%tdid%'),
		array($argv[1],$argv[2], $argv[3]),
		file_get_contents ('threatstop.conf.php')));

require_once("/usr/local/www/threatstop.conf.php");

echo "ThreatSTOP setup :\n";
echo "  pfSense version ${PF_VERSION}\n";
echo "  ThreatSTOP IP Firewall version ${TS_VERSION}\n";
echo "\n";

# account for differences between pfsense 2.2 and 2.3+
$nativefile = 'fbegin.inc';
if ( ( $PF_VERSION_MAJOR == 2 && $PF_VERSION_MINOR >= 3 ) || ( $PF_VERSION_MAJOR >= 3 ) ) {

	$nativefile = 'head.inc';
}

$tmpFile    = "/tmp/$nativefile" . '.tmp';
$bkfile     = dirname(__FILE__) . "/$nativefile" . ".old";
$nativepath = "/usr/local/www/$nativefile";

/*
 * Add Threatstop button into pfsense menu file...
 * Using raw dd
 * - grab bytes into a tmp file up to where we want our line
 * - write our line
 * - tack on the remainder
 *
 * ...but only if it's not already there (ie, key off of ThreatSTOP string....)
 */
if( strpos(file_get_contents($nativepath), 'ThreatSTOP') === false) {

	echo "Adding ThreatSTOP to firewall menu...\n";
	$beginfile = "/tmp/test.begin.tmp";
	$endfile = "/tmp/test.end.tmp";
	shell_exec('dd if=' . $nativepath . ' of=' . $beginfile . ' bs=`grep "firewall_menu = msort" ' . $nativepath . ' -bo | grep "[0-9]*" -o` count=1 2>/dev/null');
	shell_exec('dd if=' . $nativepath . ' of=' . $endfile   . ' skip=`grep "firewall_menu = msort" ' . $nativepath . ' -bo | grep "[0-9]*" -o` bs=1 2>/dev/null');
	copy($beginfile, $tmpFile);

	$fh = fopen($tmpFile, 'a') or die("can't open file $tmpFile");
	$stringData = "\$firewall_menu[] = array(\"ThreatSTOP \", \"/ts_state.php\");\n";
	fwrite($fh, $stringData);
	fclose($fh);
	file_put_contents($tmpFile, file_get_contents ($endfile), FILE_APPEND);
	copy ($nativepath,  $bkfile);
	copy ($tmpFile, $nativepath);
} else {

	echo "ThreatSTOP already found in menu; skipping...\n";
}

//Set crontab variables 
echo "Confirming periodic list updates are set...\n";
$cronUser= shell_exec('/usr/bin/crontab -l | sed -E -e "/\/(tsget|tslog)/d" ');
$blockmin = date ("i", time());
`echo "$cronUser
$blockmin */2 * * *      /usr/local/bin/php  /usr/local/www/tsgetblockip.php firewall 
0,15,30,45 * * * *      /usr/local/bin/php /usr/local/www/tslogupload.php /var/log/filter.log" |crontab -`;
$filter=file_get_contents ('/etc/inc/filter.inc');
$filternew =
	str_replace(
		"-ttt -i pflog0 | logger -t pf -p local0.info",
		"-ttt -i pflog0 | /usr/bin/sed -e 'N;s/\\\\n //;P;D;' | logger -t pf -p local0.info",
		$filter);
if (strcmp($filter, $filternew) !=0) {
	file_put_contents('filter.inc.new',$filternew);
	file_put_contents('filter.inc.org',$filter);
	echo "In order for ThreatSTOP to parse your logfiles you will need to do\n".
		"cp filter.inc.new /etc/inc/filter.inc\n".
		"and then reboot (see pfsense bug 1938 http://redmine.pfsense.org/issues/1938).\n\n";
}
echo "Installation complete.\n";

//Add ThreatStop lists
//Run tsgetblockip.php to make allow and block ThreatStop pf tables  
include '/usr/local/www/tsgetblockip.php';
echo "ThreatSTOP lists retrieved.\nYou can now enable ThreatSTOP in the pfSense webConfigurator (Firewall menu).";

?>
